"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import tendermint.abci.types_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TxResponse(google.protobuf.message.Message):
    """TxResponse defines a structure containing relevant tx data and metadata. The
    tags are stringified and the log is JSON decoded.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEIGHT_FIELD_NUMBER: builtins.int
    TXHASH_FIELD_NUMBER: builtins.int
    CODESPACE_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    RAW_LOG_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    GAS_WANTED_FIELD_NUMBER: builtins.int
    GAS_USED_FIELD_NUMBER: builtins.int
    TX_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    height: builtins.int
    """The block height"""
    txhash: builtins.str
    """The transaction hash."""
    codespace: builtins.str
    """Namespace for the Code"""
    code: builtins.int
    """Response code."""
    data: builtins.str
    """Result bytes, if any."""
    raw_log: builtins.str
    """The output of the application's logger (raw string). May be
    non-deterministic.
    """
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ABCIMessageLog]:
        """The output of the application's logger (typed). May be non-deterministic."""
    info: builtins.str
    """Additional information. May be non-deterministic."""
    gas_wanted: builtins.int
    """Amount of gas requested for transaction."""
    gas_used: builtins.int
    """Amount of gas consumed by transaction."""
    @property
    def tx(self) -> google.protobuf.any_pb2.Any:
        """The request transaction bytes."""
    timestamp: builtins.str
    """Time of the previous block. For heights > 1, it's the weighted median of
    the timestamps of the valid votes in the block.LastCommit. For height == 1,
    it's genesis time.
    """
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[tendermint.abci.types_pb2.Event]:
        """Events defines all the events emitted by processing a transaction. Note,
        these events include those emitted by processing all the messages and those
        emitted from the ante handler. Whereas Logs contains the events, with
        additional metadata, emitted only by processing the messages.

        Since: cosmos-sdk 0.42.11, 0.44.5, 0.45
        """
    def __init__(
        self,
        *,
        height: builtins.int = ...,
        txhash: builtins.str = ...,
        codespace: builtins.str = ...,
        code: builtins.int = ...,
        data: builtins.str = ...,
        raw_log: builtins.str = ...,
        logs: collections.abc.Iterable[global___ABCIMessageLog] | None = ...,
        info: builtins.str = ...,
        gas_wanted: builtins.int = ...,
        gas_used: builtins.int = ...,
        tx: google.protobuf.any_pb2.Any | None = ...,
        timestamp: builtins.str = ...,
        events: collections.abc.Iterable[tendermint.abci.types_pb2.Event] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tx", b"tx"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "codespace", b"codespace", "data", b"data", "events", b"events", "gas_used", b"gas_used", "gas_wanted", b"gas_wanted", "height", b"height", "info", b"info", "logs", b"logs", "raw_log", b"raw_log", "timestamp", b"timestamp", "tx", b"tx", "txhash", b"txhash"]) -> None: ...

global___TxResponse = TxResponse

@typing_extensions.final
class ABCIMessageLog(google.protobuf.message.Message):
    """ABCIMessageLog defines a structure containing an indexed tx ABCI message log."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_INDEX_FIELD_NUMBER: builtins.int
    LOG_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    msg_index: builtins.int
    log: builtins.str
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StringEvent]:
        """Events contains a slice of Event objects that were emitted during some
        execution.
        """
    def __init__(
        self,
        *,
        msg_index: builtins.int = ...,
        log: builtins.str = ...,
        events: collections.abc.Iterable[global___StringEvent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events", "log", b"log", "msg_index", b"msg_index"]) -> None: ...

global___ABCIMessageLog = ABCIMessageLog

@typing_extensions.final
class StringEvent(google.protobuf.message.Message):
    """StringEvent defines en Event object wrapper where all the attributes
    contain key/value pairs that are strings instead of raw bytes.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Attribute]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        attributes: collections.abc.Iterable[global___Attribute] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "type", b"type"]) -> None: ...

global___StringEvent = StringEvent

@typing_extensions.final
class Attribute(google.protobuf.message.Message):
    """Attribute defines an attribute wrapper where the key and value are
    strings instead of raw bytes.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___Attribute = Attribute

@typing_extensions.final
class GasInfo(google.protobuf.message.Message):
    """GasInfo defines tx execution gas context."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GAS_WANTED_FIELD_NUMBER: builtins.int
    GAS_USED_FIELD_NUMBER: builtins.int
    gas_wanted: builtins.int
    """GasWanted is the maximum units of work we allow this tx to perform."""
    gas_used: builtins.int
    """GasUsed is the amount of gas actually consumed."""
    def __init__(
        self,
        *,
        gas_wanted: builtins.int = ...,
        gas_used: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gas_used", b"gas_used", "gas_wanted", b"gas_wanted"]) -> None: ...

global___GasInfo = GasInfo

@typing_extensions.final
class Result(google.protobuf.message.Message):
    """Result is the union of ResponseFormat and ResponseCheckTx."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    LOG_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    data: builtins.bytes
    """Data is any data returned from message or handler execution. It MUST be
    length prefixed in order to separate data from multiple message executions.
    """
    log: builtins.str
    """Log contains the log information from message or handler execution."""
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[tendermint.abci.types_pb2.Event]:
        """Events contains a slice of Event objects that were emitted during message
        or handler execution.
        """
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
        log: builtins.str = ...,
        events: collections.abc.Iterable[tendermint.abci.types_pb2.Event] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "events", b"events", "log", b"log"]) -> None: ...

global___Result = Result

@typing_extensions.final
class SimulationResponse(google.protobuf.message.Message):
    """SimulationResponse defines the response generated when a transaction is
    successfully simulated.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GAS_INFO_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    @property
    def gas_info(self) -> global___GasInfo: ...
    @property
    def result(self) -> global___Result: ...
    def __init__(
        self,
        *,
        gas_info: global___GasInfo | None = ...,
        result: global___Result | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gas_info", b"gas_info", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gas_info", b"gas_info", "result", b"result"]) -> None: ...

global___SimulationResponse = SimulationResponse

@typing_extensions.final
class MsgData(google.protobuf.message.Message):
    """MsgData defines the data returned in a Result object during message
    execution.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    msg_type: builtins.str
    data: builtins.bytes
    def __init__(
        self,
        *,
        msg_type: builtins.str = ...,
        data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "msg_type", b"msg_type"]) -> None: ...

global___MsgData = MsgData

@typing_extensions.final
class TxMsgData(google.protobuf.message.Message):
    """TxMsgData defines a list of MsgData. A transaction will have a MsgData object
    for each message.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MsgData]: ...
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[global___MsgData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data"]) -> None: ...

global___TxMsgData = TxMsgData

@typing_extensions.final
class SearchTxsResult(google.protobuf.message.Message):
    """SearchTxsResult defines a structure for querying txs pageable"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_COUNT_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    PAGE_TOTAL_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    TXS_FIELD_NUMBER: builtins.int
    total_count: builtins.int
    """Count of all txs"""
    count: builtins.int
    """Count of txs in current page"""
    page_number: builtins.int
    """Index of current page, start from 1"""
    page_total: builtins.int
    """Count of total pages"""
    limit: builtins.int
    """Max count txs per page"""
    @property
    def txs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxResponse]:
        """List of txs in current page"""
    def __init__(
        self,
        *,
        total_count: builtins.int = ...,
        count: builtins.int = ...,
        page_number: builtins.int = ...,
        page_total: builtins.int = ...,
        limit: builtins.int = ...,
        txs: collections.abc.Iterable[global___TxResponse] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "limit", b"limit", "page_number", b"page_number", "page_total", b"page_total", "total_count", b"total_count", "txs", b"txs"]) -> None: ...

global___SearchTxsResult = SearchTxsResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Params(google.protobuf.message.Message):
    """Params holds parameters for the superfluid module"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MINIMUM_RISK_FACTOR_FIELD_NUMBER: builtins.int
    minimum_risk_factor: builtins.str
    """minimum_risk_factor is to be cut on OSMO equivalent value of lp tokens for
    superfluid staking, default: 5%. The minimum risk factor works
    to counter-balance the staked amount on chain's exposure to various asset
    volatilities, and have base staking be 'resistant' to volatility.
    """
    def __init__(
        self,
        *,
        minimum_risk_factor: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["minimum_risk_factor", b"minimum_risk_factor"]) -> None: ...

global___Params = Params



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import abc
import cosmos.authz.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Grants: grpc.UnaryUnaryMultiCallable[
        cosmos.authz.v1beta1.query_pb2.QueryGrantsRequest,
        cosmos.authz.v1beta1.query_pb2.QueryGrantsResponse,
    ]
    """Returns list of `Authorization`, granted to the grantee by the granter."""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Grants(
        self,
        request: cosmos.authz.v1beta1.query_pb2.QueryGrantsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.authz.v1beta1.query_pb2.QueryGrantsResponse:
        """Returns list of `Authorization`, granted to the grantee by the granter."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.lockup.query_pb2

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    ModuleBalance: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.ModuleBalanceRequest,
        osmosis.lockup.query_pb2.ModuleBalanceResponse,
    ]
    """Return full balance of the module"""
    ModuleLockedAmount: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.ModuleLockedAmountRequest,
        osmosis.lockup.query_pb2.ModuleLockedAmountResponse,
    ]
    """Return locked balance of the module"""
    AccountUnlockableCoins: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountUnlockableCoinsRequest,
        osmosis.lockup.query_pb2.AccountUnlockableCoinsResponse,
    ]
    """Returns unlockable coins which are not withdrawn yet"""
    AccountUnlockingCoins: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountUnlockingCoinsRequest,
        osmosis.lockup.query_pb2.AccountUnlockingCoinsResponse,
    ]
    """Returns unlocking coins"""
    AccountLockedCoins: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountLockedCoinsRequest,
        osmosis.lockup.query_pb2.AccountLockedCoinsResponse,
    ]
    """Return a locked coins that can't be withdrawn"""
    AccountLockedPastTime: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountLockedPastTimeRequest,
        osmosis.lockup.query_pb2.AccountLockedPastTimeResponse,
    ]
    """Returns locked records of an account with unlock time beyond timestamp"""
    AccountLockedPastTimeNotUnlockingOnly: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountLockedPastTimeNotUnlockingOnlyRequest,
        osmosis.lockup.query_pb2.AccountLockedPastTimeNotUnlockingOnlyResponse,
    ]
    """Returns locked records of an account with unlock time beyond timestamp
    excluding tokens started unlocking
    """
    AccountUnlockedBeforeTime: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountUnlockedBeforeTimeRequest,
        osmosis.lockup.query_pb2.AccountUnlockedBeforeTimeResponse,
    ]
    """Returns unlocked records with unlock time before timestamp"""
    AccountLockedPastTimeDenom: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountLockedPastTimeDenomRequest,
        osmosis.lockup.query_pb2.AccountLockedPastTimeDenomResponse,
    ]
    """Returns lock records by address, timestamp, denom"""
    LockedDenom: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.LockedDenomRequest,
        osmosis.lockup.query_pb2.LockedDenomResponse,
    ]
    """Returns total locked per denom with longer past given time"""
    LockedByID: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.LockedRequest,
        osmosis.lockup.query_pb2.LockedResponse,
    ]
    """Returns lock record by id"""
    SyntheticLockupsByLockupID: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.SyntheticLockupsByLockupIDRequest,
        osmosis.lockup.query_pb2.SyntheticLockupsByLockupIDResponse,
    ]
    """Returns synthetic lockups by native lockup id"""
    AccountLockedLongerDuration: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountLockedLongerDurationRequest,
        osmosis.lockup.query_pb2.AccountLockedLongerDurationResponse,
    ]
    """Returns account locked records with longer duration"""
    AccountLockedDuration: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountLockedDurationRequest,
        osmosis.lockup.query_pb2.AccountLockedDurationResponse,
    ]
    """Returns account locked records with a specific duration"""
    AccountLockedLongerDurationNotUnlockingOnly: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountLockedLongerDurationNotUnlockingOnlyRequest,
        osmosis.lockup.query_pb2.AccountLockedLongerDurationNotUnlockingOnlyResponse,
    ]
    """Returns account locked records with longer duration excluding tokens
    started unlocking
    """
    AccountLockedLongerDurationDenom: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.AccountLockedLongerDurationDenomRequest,
        osmosis.lockup.query_pb2.AccountLockedLongerDurationDenomResponse,
    ]
    """Returns account's locked records for a denom with longer duration"""
    Params: grpc.UnaryUnaryMultiCallable[
        osmosis.lockup.query_pb2.QueryParamsRequest,
        osmosis.lockup.query_pb2.QueryParamsResponse,
    ]
    """Params returns lockup params."""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def ModuleBalance(
        self,
        request: osmosis.lockup.query_pb2.ModuleBalanceRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.ModuleBalanceResponse:
        """Return full balance of the module"""
    @abc.abstractmethod
    def ModuleLockedAmount(
        self,
        request: osmosis.lockup.query_pb2.ModuleLockedAmountRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.ModuleLockedAmountResponse:
        """Return locked balance of the module"""
    @abc.abstractmethod
    def AccountUnlockableCoins(
        self,
        request: osmosis.lockup.query_pb2.AccountUnlockableCoinsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountUnlockableCoinsResponse:
        """Returns unlockable coins which are not withdrawn yet"""
    @abc.abstractmethod
    def AccountUnlockingCoins(
        self,
        request: osmosis.lockup.query_pb2.AccountUnlockingCoinsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountUnlockingCoinsResponse:
        """Returns unlocking coins"""
    @abc.abstractmethod
    def AccountLockedCoins(
        self,
        request: osmosis.lockup.query_pb2.AccountLockedCoinsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountLockedCoinsResponse:
        """Return a locked coins that can't be withdrawn"""
    @abc.abstractmethod
    def AccountLockedPastTime(
        self,
        request: osmosis.lockup.query_pb2.AccountLockedPastTimeRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountLockedPastTimeResponse:
        """Returns locked records of an account with unlock time beyond timestamp"""
    @abc.abstractmethod
    def AccountLockedPastTimeNotUnlockingOnly(
        self,
        request: osmosis.lockup.query_pb2.AccountLockedPastTimeNotUnlockingOnlyRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountLockedPastTimeNotUnlockingOnlyResponse:
        """Returns locked records of an account with unlock time beyond timestamp
        excluding tokens started unlocking
        """
    @abc.abstractmethod
    def AccountUnlockedBeforeTime(
        self,
        request: osmosis.lockup.query_pb2.AccountUnlockedBeforeTimeRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountUnlockedBeforeTimeResponse:
        """Returns unlocked records with unlock time before timestamp"""
    @abc.abstractmethod
    def AccountLockedPastTimeDenom(
        self,
        request: osmosis.lockup.query_pb2.AccountLockedPastTimeDenomRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountLockedPastTimeDenomResponse:
        """Returns lock records by address, timestamp, denom"""
    @abc.abstractmethod
    def LockedDenom(
        self,
        request: osmosis.lockup.query_pb2.LockedDenomRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.LockedDenomResponse:
        """Returns total locked per denom with longer past given time"""
    @abc.abstractmethod
    def LockedByID(
        self,
        request: osmosis.lockup.query_pb2.LockedRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.LockedResponse:
        """Returns lock record by id"""
    @abc.abstractmethod
    def SyntheticLockupsByLockupID(
        self,
        request: osmosis.lockup.query_pb2.SyntheticLockupsByLockupIDRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.SyntheticLockupsByLockupIDResponse:
        """Returns synthetic lockups by native lockup id"""
    @abc.abstractmethod
    def AccountLockedLongerDuration(
        self,
        request: osmosis.lockup.query_pb2.AccountLockedLongerDurationRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountLockedLongerDurationResponse:
        """Returns account locked records with longer duration"""
    @abc.abstractmethod
    def AccountLockedDuration(
        self,
        request: osmosis.lockup.query_pb2.AccountLockedDurationRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountLockedDurationResponse:
        """Returns account locked records with a specific duration"""
    @abc.abstractmethod
    def AccountLockedLongerDurationNotUnlockingOnly(
        self,
        request: osmosis.lockup.query_pb2.AccountLockedLongerDurationNotUnlockingOnlyRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountLockedLongerDurationNotUnlockingOnlyResponse:
        """Returns account locked records with longer duration excluding tokens
        started unlocking
        """
    @abc.abstractmethod
    def AccountLockedLongerDurationDenom(
        self,
        request: osmosis.lockup.query_pb2.AccountLockedLongerDurationDenomRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.AccountLockedLongerDurationDenomResponse:
        """Returns account's locked records for a denom with longer duration"""
    @abc.abstractmethod
    def Params(
        self,
        request: osmosis.lockup.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.lockup.query_pb2.QueryParamsResponse:
        """Params returns lockup params."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/incentives/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from osmosis.incentives import params_pb2 as osmosis_dot_incentives_dot_params__pb2
from osmosis.incentives import gauge_pb2 as osmosis_dot_incentives_dot_gauge__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n osmosis/incentives/genesis.proto\x12\x12osmosis.incentives\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fosmosis/incentives/params.proto\x1a\x1eosmosis/incentives/gauge.proto\"\xe6\x01\n\x0cGenesisState\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.osmosis.incentives.ParamsB\x04\xc8\xde\x1f\x00\x12/\n\x06gauges\x18\x02 \x03(\x0b\x32\x19.osmosis.incentives.GaugeB\x04\xc8\xde\x1f\x00\x12\\\n\x12lockable_durations\x18\x03 \x03(\x0b\x32\x19.google.protobuf.DurationB%\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x19yaml:\"lockable_durations\"\x12\x15\n\rlast_gauge_id\x18\x04 \x01(\x04\x42\x38Z6github.com/osmosis-labs/osmosis/v14/x/incentives/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.incentives.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/osmosis-labs/osmosis/v14/x/incentives/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['gauges']._options = None
  _GENESISSTATE.fields_by_name['gauges']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['lockable_durations']._options = None
  _GENESISSTATE.fields_by_name['lockable_durations']._serialized_options = b'\310\336\037\000\230\337\037\001\362\336\037\031yaml:\"lockable_durations\"'
  _GENESISSTATE._serialized_start=176
  _GENESISSTATE._serialized_end=406
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Protocol Buffers for Go with Gadgets

Copyright (c) 2013, The GoGo Authors. All rights reserved.
http://github.com/gogo/protobuf

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

GOPROTO_ENUM_PREFIX_FIELD_NUMBER: builtins.int
GOPROTO_ENUM_STRINGER_FIELD_NUMBER: builtins.int
ENUM_STRINGER_FIELD_NUMBER: builtins.int
ENUM_CUSTOMNAME_FIELD_NUMBER: builtins.int
ENUMDECL_FIELD_NUMBER: builtins.int
ENUMVALUE_CUSTOMNAME_FIELD_NUMBER: builtins.int
GOPROTO_GETTERS_ALL_FIELD_NUMBER: builtins.int
GOPROTO_ENUM_PREFIX_ALL_FIELD_NUMBER: builtins.int
GOPROTO_STRINGER_ALL_FIELD_NUMBER: builtins.int
VERBOSE_EQUAL_ALL_FIELD_NUMBER: builtins.int
FACE_ALL_FIELD_NUMBER: builtins.int
GOSTRING_ALL_FIELD_NUMBER: builtins.int
POPULATE_ALL_FIELD_NUMBER: builtins.int
STRINGER_ALL_FIELD_NUMBER: builtins.int
ONLYONE_ALL_FIELD_NUMBER: builtins.int
EQUAL_ALL_FIELD_NUMBER: builtins.int
DESCRIPTION_ALL_FIELD_NUMBER: builtins.int
TESTGEN_ALL_FIELD_NUMBER: builtins.int
BENCHGEN_ALL_FIELD_NUMBER: builtins.int
MARSHALER_ALL_FIELD_NUMBER: builtins.int
UNMARSHALER_ALL_FIELD_NUMBER: builtins.int
STABLE_MARSHALER_ALL_FIELD_NUMBER: builtins.int
SIZER_ALL_FIELD_NUMBER: builtins.int
GOPROTO_ENUM_STRINGER_ALL_FIELD_NUMBER: builtins.int
ENUM_STRINGER_ALL_FIELD_NUMBER: builtins.int
UNSAFE_MARSHALER_ALL_FIELD_NUMBER: builtins.int
UNSAFE_UNMARSHALER_ALL_FIELD_NUMBER: builtins.int
GOPROTO_EXTENSIONS_MAP_ALL_FIELD_NUMBER: builtins.int
GOPROTO_UNRECOGNIZED_ALL_FIELD_NUMBER: builtins.int
GOGOPROTO_IMPORT_FIELD_NUMBER: builtins.int
PROTOSIZER_ALL_FIELD_NUMBER: builtins.int
COMPARE_ALL_FIELD_NUMBER: builtins.int
TYPEDECL_ALL_FIELD_NUMBER: builtins.int
ENUMDECL_ALL_FIELD_NUMBER: builtins.int
GOPROTO_REGISTRATION_FIELD_NUMBER: builtins.int
MESSAGENAME_ALL_FIELD_NUMBER: builtins.int
GOPROTO_SIZECACHE_ALL_FIELD_NUMBER: builtins.int
GOPROTO_UNKEYED_ALL_FIELD_NUMBER: builtins.int
GOPROTO_GETTERS_FIELD_NUMBER: builtins.int
GOPROTO_STRINGER_FIELD_NUMBER: builtins.int
VERBOSE_EQUAL_FIELD_NUMBER: builtins.int
FACE_FIELD_NUMBER: builtins.int
GOSTRING_FIELD_NUMBER: builtins.int
POPULATE_FIELD_NUMBER: builtins.int
STRINGER_FIELD_NUMBER: builtins.int
ONLYONE_FIELD_NUMBER: builtins.int
EQUAL_FIELD_NUMBER: builtins.int
DESCRIPTION_FIELD_NUMBER: builtins.int
TESTGEN_FIELD_NUMBER: builtins.int
BENCHGEN_FIELD_NUMBER: builtins.int
MARSHALER_FIELD_NUMBER: builtins.int
UNMARSHALER_FIELD_NUMBER: builtins.int
STABLE_MARSHALER_FIELD_NUMBER: builtins.int
SIZER_FIELD_NUMBER: builtins.int
UNSAFE_MARSHALER_FIELD_NUMBER: builtins.int
UNSAFE_UNMARSHALER_FIELD_NUMBER: builtins.int
GOPROTO_EXTENSIONS_MAP_FIELD_NUMBER: builtins.int
GOPROTO_UNRECOGNIZED_FIELD_NUMBER: builtins.int
PROTOSIZER_FIELD_NUMBER: builtins.int
COMPARE_FIELD_NUMBER: builtins.int
TYPEDECL_FIELD_NUMBER: builtins.int
MESSAGENAME_FIELD_NUMBER: builtins.int
GOPROTO_SIZECACHE_FIELD_NUMBER: builtins.int
GOPROTO_UNKEYED_FIELD_NUMBER: builtins.int
NULLABLE_FIELD_NUMBER: builtins.int
EMBED_FIELD_NUMBER: builtins.int
CUSTOMTYPE_FIELD_NUMBER: builtins.int
CUSTOMNAME_FIELD_NUMBER: builtins.int
JSONTAG_FIELD_NUMBER: builtins.int
MORETAGS_FIELD_NUMBER: builtins.int
CASTTYPE_FIELD_NUMBER: builtins.int
CASTKEY_FIELD_NUMBER: builtins.int
CASTVALUE_FIELD_NUMBER: builtins.int
STDTIME_FIELD_NUMBER: builtins.int
STDDURATION_FIELD_NUMBER: builtins.int
WKTPOINTER_FIELD_NUMBER: builtins.int
CASTREPEATED_FIELD_NUMBER: builtins.int
goproto_enum_prefix: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumOptions, builtins.bool]
goproto_enum_stringer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumOptions, builtins.bool]
enum_stringer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumOptions, builtins.bool]
enum_customname: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumOptions, builtins.str]
enumdecl: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumOptions, builtins.bool]
enumvalue_customname: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.EnumValueOptions, builtins.str]
goproto_getters_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_enum_prefix_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_stringer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
verbose_equal_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
face_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
gostring_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
populate_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
stringer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
onlyone_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
equal_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
description_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
testgen_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
benchgen_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
marshaler_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
unmarshaler_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
stable_marshaler_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
sizer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_enum_stringer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
enum_stringer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
unsafe_marshaler_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
unsafe_unmarshaler_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_extensions_map_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_unrecognized_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
gogoproto_import: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
protosizer_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
compare_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
typedecl_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
enumdecl_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_registration: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
messagename_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_sizecache_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_unkeyed_all: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FileOptions, builtins.bool]
goproto_getters: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
goproto_stringer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
verbose_equal: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
face: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
gostring: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
populate: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
stringer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
onlyone: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
equal: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
description: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
testgen: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
benchgen: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
marshaler: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
unmarshaler: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
stable_marshaler: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
sizer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
unsafe_marshaler: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
unsafe_unmarshaler: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
goproto_extensions_map: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
goproto_unrecognized: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
protosizer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
compare: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
typedecl: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
messagename: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
goproto_sizecache: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
goproto_unkeyed: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
nullable: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
embed: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
customtype: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
customname: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
jsontag: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
moretags: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
casttype: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
castkey: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
castvalue: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
stdtime: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
stdduration: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
wktpointer: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
castrepeated: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BasicAllowance(google.protobuf.message.Message):
    """BasicAllowance implements Allowance with a one-time grant of tokens
    that optionally expires. The grantee can use up to SpendLimit to cover fees.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEND_LIMIT_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    @property
    def spend_limit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """spend_limit specifies the maximum amount of tokens that can be spent
        by this allowance and will be updated as tokens are spent. If it is
        empty, there is no spend limit and any amount of coins can be spent.
        """
    @property
    def expiration(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """expiration specifies an optional time when this allowance expires"""
    def __init__(
        self,
        *,
        spend_limit: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        expiration: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expiration", b"expiration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration", b"expiration", "spend_limit", b"spend_limit"]) -> None: ...

global___BasicAllowance = BasicAllowance

@typing_extensions.final
class PeriodicAllowance(google.protobuf.message.Message):
    """PeriodicAllowance extends Allowance to allow for both a maximum cap,
    as well as a limit per time period.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASIC_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    PERIOD_SPEND_LIMIT_FIELD_NUMBER: builtins.int
    PERIOD_CAN_SPEND_FIELD_NUMBER: builtins.int
    PERIOD_RESET_FIELD_NUMBER: builtins.int
    @property
    def basic(self) -> global___BasicAllowance:
        """basic specifies a struct of `BasicAllowance`"""
    @property
    def period(self) -> google.protobuf.duration_pb2.Duration:
        """period specifies the time duration in which period_spend_limit coins can
        be spent before that allowance is reset
        """
    @property
    def period_spend_limit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """period_spend_limit specifies the maximum number of coins that can be spent
        in the period
        """
    @property
    def period_can_spend(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """period_can_spend is the number of coins left to be spent before the period_reset time"""
    @property
    def period_reset(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """period_reset is the time at which this period resets and a new one begins,
        it is calculated from the start time of the first transaction after the
        last period ended
        """
    def __init__(
        self,
        *,
        basic: global___BasicAllowance | None = ...,
        period: google.protobuf.duration_pb2.Duration | None = ...,
        period_spend_limit: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        period_can_spend: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        period_reset: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["basic", b"basic", "period", b"period", "period_reset", b"period_reset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["basic", b"basic", "period", b"period", "period_can_spend", b"period_can_spend", "period_reset", b"period_reset", "period_spend_limit", b"period_spend_limit"]) -> None: ...

global___PeriodicAllowance = PeriodicAllowance

@typing_extensions.final
class AllowedMsgAllowance(google.protobuf.message.Message):
    """AllowedMsgAllowance creates allowance only for specified message types."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWANCE_FIELD_NUMBER: builtins.int
    ALLOWED_MESSAGES_FIELD_NUMBER: builtins.int
    @property
    def allowance(self) -> google.protobuf.any_pb2.Any:
        """allowance can be any of basic and filtered fee allowance."""
    @property
    def allowed_messages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """allowed_messages are the messages for which the grantee has the access."""
    def __init__(
        self,
        *,
        allowance: google.protobuf.any_pb2.Any | None = ...,
        allowed_messages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allowance", b"allowance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowance", b"allowance", "allowed_messages", b"allowed_messages"]) -> None: ...

global___AllowedMsgAllowance = AllowedMsgAllowance

@typing_extensions.final
class Grant(google.protobuf.message.Message):
    """Grant is stored in the KVStore to record a grant with full context"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    ALLOWANCE_FIELD_NUMBER: builtins.int
    granter: builtins.str
    """granter is the address of the user granting an allowance of their funds."""
    grantee: builtins.str
    """grantee is the address of the user being granted an allowance of another user's funds."""
    @property
    def allowance(self) -> google.protobuf.any_pb2.Any:
        """allowance can be any of basic and filtered fee allowance."""
    def __init__(
        self,
        *,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
        allowance: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allowance", b"allowance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowance", b"allowance", "grantee", b"grantee", "granter", b"granter"]) -> None: ...

global___Grant = Grant



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.txfees.v1beta1.feetoken_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the txfees module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASEDENOM_FIELD_NUMBER: builtins.int
    FEETOKENS_FIELD_NUMBER: builtins.int
    basedenom: builtins.str
    @property
    def feetokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.txfees.v1beta1.feetoken_pb2.FeeToken]: ...
    def __init__(
        self,
        *,
        basedenom: builtins.str = ...,
        feetokens: collections.abc.Iterable[osmosis.txfees.v1beta1.feetoken_pb2.FeeToken] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["basedenom", b"basedenom", "feetokens", b"feetokens"]) -> None: ...

global___GenesisState = GenesisState



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.superfluid import tx_pb2 as osmosis_dot_superfluid_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SuperfluidDelegate = channel.unary_unary(
                '/osmosis.superfluid.Msg/SuperfluidDelegate',
                request_serializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidDelegate.SerializeToString,
                response_deserializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidDelegateResponse.FromString,
                )
        self.SuperfluidUndelegate = channel.unary_unary(
                '/osmosis.superfluid.Msg/SuperfluidUndelegate',
                request_serializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUndelegate.SerializeToString,
                response_deserializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUndelegateResponse.FromString,
                )
        self.SuperfluidUnbondLock = channel.unary_unary(
                '/osmosis.superfluid.Msg/SuperfluidUnbondLock',
                request_serializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUnbondLock.SerializeToString,
                response_deserializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUnbondLockResponse.FromString,
                )
        self.LockAndSuperfluidDelegate = channel.unary_unary(
                '/osmosis.superfluid.Msg/LockAndSuperfluidDelegate',
                request_serializer=osmosis_dot_superfluid_dot_tx__pb2.MsgLockAndSuperfluidDelegate.SerializeToString,
                response_deserializer=osmosis_dot_superfluid_dot_tx__pb2.MsgLockAndSuperfluidDelegateResponse.FromString,
                )
        self.UnPoolWhitelistedPool = channel.unary_unary(
                '/osmosis.superfluid.Msg/UnPoolWhitelistedPool',
                request_serializer=osmosis_dot_superfluid_dot_tx__pb2.MsgUnPoolWhitelistedPool.SerializeToString,
                response_deserializer=osmosis_dot_superfluid_dot_tx__pb2.MsgUnPoolWhitelistedPoolResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def SuperfluidDelegate(self, request, context):
        """Execute superfluid delegation for a lockup
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SuperfluidUndelegate(self, request, context):
        """Execute superfluid undelegation for a lockup
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SuperfluidUnbondLock(self, request, context):
        """Execute superfluid redelegation for a lockup
        rpc SuperfluidRedelegate(MsgSuperfluidRedelegate) returns
        (MsgSuperfluidRedelegateResponse);

        For a given lock that is being superfluidly undelegated,
        also unbond the underlying lock.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LockAndSuperfluidDelegate(self, request, context):
        """Execute lockup lock and superfluid delegation in a single msg
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnPoolWhitelistedPool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SuperfluidDelegate': grpc.unary_unary_rpc_method_handler(
                    servicer.SuperfluidDelegate,
                    request_deserializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidDelegate.FromString,
                    response_serializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidDelegateResponse.SerializeToString,
            ),
            'SuperfluidUndelegate': grpc.unary_unary_rpc_method_handler(
                    servicer.SuperfluidUndelegate,
                    request_deserializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUndelegate.FromString,
                    response_serializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUndelegateResponse.SerializeToString,
            ),
            'SuperfluidUnbondLock': grpc.unary_unary_rpc_method_handler(
                    servicer.SuperfluidUnbondLock,
                    request_deserializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUnbondLock.FromString,
                    response_serializer=osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUnbondLockResponse.SerializeToString,
            ),
            'LockAndSuperfluidDelegate': grpc.unary_unary_rpc_method_handler(
                    servicer.LockAndSuperfluidDelegate,
                    request_deserializer=osmosis_dot_superfluid_dot_tx__pb2.MsgLockAndSuperfluidDelegate.FromString,
                    response_serializer=osmosis_dot_superfluid_dot_tx__pb2.MsgLockAndSuperfluidDelegateResponse.SerializeToString,
            ),
            'UnPoolWhitelistedPool': grpc.unary_unary_rpc_method_handler(
                    servicer.UnPoolWhitelistedPool,
                    request_deserializer=osmosis_dot_superfluid_dot_tx__pb2.MsgUnPoolWhitelistedPool.FromString,
                    response_serializer=osmosis_dot_superfluid_dot_tx__pb2.MsgUnPoolWhitelistedPoolResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.superfluid.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def SuperfluidDelegate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.superfluid.Msg/SuperfluidDelegate',
            osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidDelegate.SerializeToString,
            osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidDelegateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SuperfluidUndelegate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.superfluid.Msg/SuperfluidUndelegate',
            osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUndelegate.SerializeToString,
            osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUndelegateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SuperfluidUnbondLock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.superfluid.Msg/SuperfluidUnbondLock',
            osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUnbondLock.SerializeToString,
            osmosis_dot_superfluid_dot_tx__pb2.MsgSuperfluidUnbondLockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LockAndSuperfluidDelegate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.superfluid.Msg/LockAndSuperfluidDelegate',
            osmosis_dot_superfluid_dot_tx__pb2.MsgLockAndSuperfluidDelegate.SerializeToString,
            osmosis_dot_superfluid_dot_tx__pb2.MsgLockAndSuperfluidDelegateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnPoolWhitelistedPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.superfluid.Msg/UnPoolWhitelistedPool',
            osmosis_dot_superfluid_dot_tx__pb2.MsgUnPoolWhitelistedPool.SerializeToString,
            osmosis_dot_superfluid_dot_tx__pb2.MsgUnPoolWhitelistedPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.epochs.query_pb2

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    EpochInfos: grpc.UnaryUnaryMultiCallable[
        osmosis.epochs.query_pb2.QueryEpochsInfoRequest,
        osmosis.epochs.query_pb2.QueryEpochsInfoResponse,
    ]
    """EpochInfos provide running epochInfos"""
    CurrentEpoch: grpc.UnaryUnaryMultiCallable[
        osmosis.epochs.query_pb2.QueryCurrentEpochRequest,
        osmosis.epochs.query_pb2.QueryCurrentEpochResponse,
    ]
    """CurrentEpoch provide current epoch of specified identifier"""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def EpochInfos(
        self,
        request: osmosis.epochs.query_pb2.QueryEpochsInfoRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.epochs.query_pb2.QueryEpochsInfoResponse:
        """EpochInfos provide running epochInfos"""
    @abc.abstractmethod
    def CurrentEpoch(
        self,
        request: osmosis.epochs.query_pb2.QueryCurrentEpochRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.epochs.query_pb2.QueryCurrentEpochResponse:
        """CurrentEpoch provide current epoch of specified identifier"""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.upgrade.v1beta1.upgrade_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryCurrentPlanRequest(google.protobuf.message.Message):
    """QueryCurrentPlanRequest is the request type for the Query/CurrentPlan RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryCurrentPlanRequest = QueryCurrentPlanRequest

@typing_extensions.final
class QueryCurrentPlanResponse(google.protobuf.message.Message):
    """QueryCurrentPlanResponse is the response type for the Query/CurrentPlan RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAN_FIELD_NUMBER: builtins.int
    @property
    def plan(self) -> cosmos.upgrade.v1beta1.upgrade_pb2.Plan:
        """plan is the current upgrade plan."""
    def __init__(
        self,
        *,
        plan: cosmos.upgrade.v1beta1.upgrade_pb2.Plan | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["plan", b"plan"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["plan", b"plan"]) -> None: ...

global___QueryCurrentPlanResponse = QueryCurrentPlanResponse

@typing_extensions.final
class QueryAppliedPlanRequest(google.protobuf.message.Message):
    """QueryCurrentPlanRequest is the request type for the Query/AppliedPlan RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """name is the name of the applied plan to query for."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___QueryAppliedPlanRequest = QueryAppliedPlanRequest

@typing_extensions.final
class QueryAppliedPlanResponse(google.protobuf.message.Message):
    """QueryAppliedPlanResponse is the response type for the Query/AppliedPlan RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEIGHT_FIELD_NUMBER: builtins.int
    height: builtins.int
    """height is the block height at which the plan was applied."""
    def __init__(
        self,
        *,
        height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height"]) -> None: ...

global___QueryAppliedPlanResponse = QueryAppliedPlanResponse

@typing_extensions.final
class QueryUpgradedConsensusStateRequest(google.protobuf.message.Message):
    """QueryUpgradedConsensusStateRequest is the request type for the Query/UpgradedConsensusState
    RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_HEIGHT_FIELD_NUMBER: builtins.int
    last_height: builtins.int
    """last height of the current chain must be sent in request
    as this is the height under which next consensus state is stored
    """
    def __init__(
        self,
        *,
        last_height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_height", b"last_height"]) -> None: ...

global___QueryUpgradedConsensusStateRequest = QueryUpgradedConsensusStateRequest

@typing_extensions.final
class QueryUpgradedConsensusStateResponse(google.protobuf.message.Message):
    """QueryUpgradedConsensusStateResponse is the response type for the Query/UpgradedConsensusState
    RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPGRADED_CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    upgraded_consensus_state: builtins.bytes
    """Since: cosmos-sdk 0.43"""
    def __init__(
        self,
        *,
        upgraded_consensus_state: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["upgraded_consensus_state", b"upgraded_consensus_state"]) -> None: ...

global___QueryUpgradedConsensusStateResponse = QueryUpgradedConsensusStateResponse

@typing_extensions.final
class QueryModuleVersionsRequest(google.protobuf.message.Message):
    """QueryModuleVersionsRequest is the request type for the Query/ModuleVersions
    RPC method.

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_NAME_FIELD_NUMBER: builtins.int
    module_name: builtins.str
    """module_name is a field to query a specific module
    consensus version from state. Leaving this empty will
    fetch the full list of module versions from state
    """
    def __init__(
        self,
        *,
        module_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_name", b"module_name"]) -> None: ...

global___QueryModuleVersionsRequest = QueryModuleVersionsRequest

@typing_extensions.final
class QueryModuleVersionsResponse(google.protobuf.message.Message):
    """QueryModuleVersionsResponse is the response type for the Query/ModuleVersions
    RPC method.

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_VERSIONS_FIELD_NUMBER: builtins.int
    @property
    def module_versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.upgrade.v1beta1.upgrade_pb2.ModuleVersion]:
        """module_versions is a list of module names with their consensus versions."""
    def __init__(
        self,
        *,
        module_versions: collections.abc.Iterable[cosmos.upgrade.v1beta1.upgrade_pb2.ModuleVersion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_versions", b"module_versions"]) -> None: ...

global___QueryModuleVersionsResponse = QueryModuleVersionsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PublicKey(google.protobuf.message.Message):
    """PublicKey defines the keys available for use with Tendermint Validators"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ED25519_FIELD_NUMBER: builtins.int
    SECP256K1_FIELD_NUMBER: builtins.int
    ed25519: builtins.bytes
    secp256k1: builtins.bytes
    def __init__(
        self,
        *,
        ed25519: builtins.bytes = ...,
        secp256k1: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ed25519", b"ed25519", "secp256k1", b"secp256k1", "sum", b"sum"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ed25519", b"ed25519", "secp256k1", b"secp256k1", "sum", b"sum"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["sum", b"sum"]) -> typing_extensions.Literal["ed25519", "secp256k1"] | None: ...

global___PublicKey = PublicKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.gamm.v1beta1.tx_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryPoolRequest(google.protobuf.message.Message):
    """=============================== Pool"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id"]) -> None: ...

global___QueryPoolRequest = QueryPoolRequest

@typing_extensions.final
class QueryPoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_FIELD_NUMBER: builtins.int
    @property
    def pool(self) -> google.protobuf.any_pb2.Any: ...
    def __init__(
        self,
        *,
        pool: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pool", b"pool"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool", b"pool"]) -> None: ...

global___QueryPoolResponse = QueryPoolResponse

@typing_extensions.final
class QueryPoolsRequest(google.protobuf.message.Message):
    """=============================== Pools"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___QueryPoolsRequest = QueryPoolsRequest

@typing_extensions.final
class QueryPoolsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOLS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        pools: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "pools", b"pools"]) -> None: ...

global___QueryPoolsResponse = QueryPoolsResponse

@typing_extensions.final
class QueryNumPoolsRequest(google.protobuf.message.Message):
    """=============================== NumPools"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryNumPoolsRequest = QueryNumPoolsRequest

@typing_extensions.final
class QueryNumPoolsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_POOLS_FIELD_NUMBER: builtins.int
    num_pools: builtins.int
    def __init__(
        self,
        *,
        num_pools: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_pools", b"num_pools"]) -> None: ...

global___QueryNumPoolsResponse = QueryNumPoolsResponse

@typing_extensions.final
class QueryPoolTypeRequest(google.protobuf.message.Message):
    """=============================== PoolType"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id"]) -> None: ...

global___QueryPoolTypeRequest = QueryPoolTypeRequest

@typing_extensions.final
class QueryPoolTypeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_TYPE_FIELD_NUMBER: builtins.int
    pool_type: builtins.str
    def __init__(
        self,
        *,
        pool_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_type", b"pool_type"]) -> None: ...

global___QueryPoolTypeResponse = QueryPoolTypeResponse

@typing_extensions.final
class QueryCalcJoinPoolSharesRequest(google.protobuf.message.Message):
    """=============================== CalcJoinPoolShares"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    TOKENS_IN_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    @property
    def tokens_in(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        tokens_in: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "tokens_in", b"tokens_in"]) -> None: ...

global___QueryCalcJoinPoolSharesRequest = QueryCalcJoinPoolSharesRequest

@typing_extensions.final
class QueryCalcJoinPoolSharesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARE_OUT_AMOUNT_FIELD_NUMBER: builtins.int
    TOKENS_OUT_FIELD_NUMBER: builtins.int
    share_out_amount: builtins.str
    @property
    def tokens_out(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        share_out_amount: builtins.str = ...,
        tokens_out: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_out_amount", b"share_out_amount", "tokens_out", b"tokens_out"]) -> None: ...

global___QueryCalcJoinPoolSharesResponse = QueryCalcJoinPoolSharesResponse

@typing_extensions.final
class QueryCalcExitPoolCoinsFromSharesRequest(google.protobuf.message.Message):
    """=============================== CalcExitPoolCoinsFromShares"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    SHARE_IN_AMOUNT_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    share_in_amount: builtins.str
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        share_in_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "share_in_amount", b"share_in_amount"]) -> None: ...

global___QueryCalcExitPoolCoinsFromSharesRequest = QueryCalcExitPoolCoinsFromSharesRequest

@typing_extensions.final
class QueryCalcExitPoolCoinsFromSharesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKENS_OUT_FIELD_NUMBER: builtins.int
    @property
    def tokens_out(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        tokens_out: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tokens_out", b"tokens_out"]) -> None: ...

global___QueryCalcExitPoolCoinsFromSharesResponse = QueryCalcExitPoolCoinsFromSharesResponse

@typing_extensions.final
class QueryPoolParamsRequest(google.protobuf.message.Message):
    """=============================== PoolParams"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id"]) -> None: ...

global___QueryPoolParamsRequest = QueryPoolParamsRequest

@typing_extensions.final
class QueryPoolParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> google.protobuf.any_pb2.Any: ...
    def __init__(
        self,
        *,
        params: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___QueryPoolParamsResponse = QueryPoolParamsResponse

@typing_extensions.final
class QueryTotalPoolLiquidityRequest(google.protobuf.message.Message):
    """=============================== PoolLiquidity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id"]) -> None: ...

global___QueryTotalPoolLiquidityRequest = QueryTotalPoolLiquidityRequest

@typing_extensions.final
class QueryTotalPoolLiquidityResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIQUIDITY_FIELD_NUMBER: builtins.int
    @property
    def liquidity(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        liquidity: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["liquidity", b"liquidity"]) -> None: ...

global___QueryTotalPoolLiquidityResponse = QueryTotalPoolLiquidityResponse

@typing_extensions.final
class QueryTotalSharesRequest(google.protobuf.message.Message):
    """=============================== TotalShares"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id"]) -> None: ...

global___QueryTotalSharesRequest = QueryTotalSharesRequest

@typing_extensions.final
class QueryTotalSharesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_SHARES_FIELD_NUMBER: builtins.int
    @property
    def total_shares(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(
        self,
        *,
        total_shares: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["total_shares", b"total_shares"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["total_shares", b"total_shares"]) -> None: ...

global___QueryTotalSharesResponse = QueryTotalSharesResponse

@typing_extensions.final
class QueryCalcJoinPoolNoSwapSharesRequest(google.protobuf.message.Message):
    """=============================== CalcJoinPoolNoSwapShares"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    TOKENS_IN_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    @property
    def tokens_in(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        tokens_in: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "tokens_in", b"tokens_in"]) -> None: ...

global___QueryCalcJoinPoolNoSwapSharesRequest = QueryCalcJoinPoolNoSwapSharesRequest

@typing_extensions.final
class QueryCalcJoinPoolNoSwapSharesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKENS_OUT_FIELD_NUMBER: builtins.int
    SHARES_OUT_FIELD_NUMBER: builtins.int
    @property
    def tokens_out(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    shares_out: builtins.str
    def __init__(
        self,
        *,
        tokens_out: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        shares_out: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["shares_out", b"shares_out", "tokens_out", b"tokens_out"]) -> None: ...

global___QueryCalcJoinPoolNoSwapSharesResponse = QueryCalcJoinPoolNoSwapSharesResponse

@typing_extensions.final
class QuerySpotPriceRequest(google.protobuf.message.Message):
    """QuerySpotPriceRequest defines the gRPC request structure for a SpotPrice
    query.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    BASE_ASSET_DENOM_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_DENOM_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    base_asset_denom: builtins.str
    quote_asset_denom: builtins.str
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        base_asset_denom: builtins.str = ...,
        quote_asset_denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset_denom", b"base_asset_denom", "pool_id", b"pool_id", "quote_asset_denom", b"quote_asset_denom"]) -> None: ...

global___QuerySpotPriceRequest = QuerySpotPriceRequest

@typing_extensions.final
class QueryPoolsWithFilterRequest(google.protobuf.message.Message):
    """=============================== PoolsWithFilter"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_LIQUIDITY_FIELD_NUMBER: builtins.int
    POOL_TYPE_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    min_liquidity: builtins.str
    """String of the coins in single string seperated by comma. Ex)
    10uatom,100uosmo
    """
    pool_type: builtins.str
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...
    def __init__(
        self,
        *,
        min_liquidity: builtins.str = ...,
        pool_type: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_liquidity", b"min_liquidity", "pagination", b"pagination", "pool_type", b"pool_type"]) -> None: ...

global___QueryPoolsWithFilterRequest = QueryPoolsWithFilterRequest

@typing_extensions.final
class QueryPoolsWithFilterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOLS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        pools: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "pools", b"pools"]) -> None: ...

global___QueryPoolsWithFilterResponse = QueryPoolsWithFilterResponse

@typing_extensions.final
class QuerySpotPriceResponse(google.protobuf.message.Message):
    """QuerySpotPriceResponse defines the gRPC response structure for a SpotPrice
    query.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPOT_PRICE_FIELD_NUMBER: builtins.int
    spot_price: builtins.str
    """String of the Dec. Ex) 10.203uatom"""
    def __init__(
        self,
        *,
        spot_price: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["spot_price", b"spot_price"]) -> None: ...

global___QuerySpotPriceResponse = QuerySpotPriceResponse

@typing_extensions.final
class QuerySwapExactAmountInRequest(google.protobuf.message.Message):
    """=============================== EstimateSwapExactAmountIn"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    TOKEN_IN_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    sender: builtins.str
    """TODO: CHANGE THIS TO RESERVED IN A PATCH RELEASE"""
    pool_id: builtins.int
    token_in: builtins.str
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.gamm.v1beta1.tx_pb2.SwapAmountInRoute]: ...
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
        token_in: builtins.str = ...,
        routes: collections.abc.Iterable[osmosis.gamm.v1beta1.tx_pb2.SwapAmountInRoute] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "routes", b"routes", "sender", b"sender", "token_in", b"token_in"]) -> None: ...

global___QuerySwapExactAmountInRequest = QuerySwapExactAmountInRequest

@typing_extensions.final
class QuerySwapExactAmountInResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_OUT_AMOUNT_FIELD_NUMBER: builtins.int
    token_out_amount: builtins.str
    def __init__(
        self,
        *,
        token_out_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_out_amount", b"token_out_amount"]) -> None: ...

global___QuerySwapExactAmountInResponse = QuerySwapExactAmountInResponse

@typing_extensions.final
class QuerySwapExactAmountOutRequest(google.protobuf.message.Message):
    """=============================== EstimateSwapExactAmountOut"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    TOKEN_OUT_FIELD_NUMBER: builtins.int
    sender: builtins.str
    """TODO: CHANGE THIS TO RESERVED IN A PATCH RELEASE"""
    pool_id: builtins.int
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.gamm.v1beta1.tx_pb2.SwapAmountOutRoute]: ...
    token_out: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
        routes: collections.abc.Iterable[osmosis.gamm.v1beta1.tx_pb2.SwapAmountOutRoute] | None = ...,
        token_out: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "routes", b"routes", "sender", b"sender", "token_out", b"token_out"]) -> None: ...

global___QuerySwapExactAmountOutRequest = QuerySwapExactAmountOutRequest

@typing_extensions.final
class QuerySwapExactAmountOutResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_IN_AMOUNT_FIELD_NUMBER: builtins.int
    token_in_amount: builtins.str
    def __init__(
        self,
        *,
        token_in_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_in_amount", b"token_in_amount"]) -> None: ...

global___QuerySwapExactAmountOutResponse = QuerySwapExactAmountOutResponse

@typing_extensions.final
class QueryTotalLiquidityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryTotalLiquidityRequest = QueryTotalLiquidityRequest

@typing_extensions.final
class QueryTotalLiquidityResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIQUIDITY_FIELD_NUMBER: builtins.int
    @property
    def liquidity(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        liquidity: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["liquidity", b"liquidity"]) -> None: ...

global___QueryTotalLiquidityResponse = QueryTotalLiquidityResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.slashing.v1beta1.slashing_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest is the request type for the Query/Params RPC method"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryParamsRequest = QueryParamsRequest

@typing_extensions.final
class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is the response type for the Query/Params RPC method"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.slashing.v1beta1.slashing_pb2.Params: ...
    def __init__(
        self,
        *,
        params: cosmos.slashing.v1beta1.slashing_pb2.Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___QueryParamsResponse = QueryParamsResponse

@typing_extensions.final
class QuerySigningInfoRequest(google.protobuf.message.Message):
    """QuerySigningInfoRequest is the request type for the Query/SigningInfo RPC
    method
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONS_ADDRESS_FIELD_NUMBER: builtins.int
    cons_address: builtins.str
    """cons_address is the address to query signing info of"""
    def __init__(
        self,
        *,
        cons_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cons_address", b"cons_address"]) -> None: ...

global___QuerySigningInfoRequest = QuerySigningInfoRequest

@typing_extensions.final
class QuerySigningInfoResponse(google.protobuf.message.Message):
    """QuerySigningInfoResponse is the response type for the Query/SigningInfo RPC
    method
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAL_SIGNING_INFO_FIELD_NUMBER: builtins.int
    @property
    def val_signing_info(self) -> cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo:
        """val_signing_info is the signing info of requested val cons address"""
    def __init__(
        self,
        *,
        val_signing_info: cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["val_signing_info", b"val_signing_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["val_signing_info", b"val_signing_info"]) -> None: ...

global___QuerySigningInfoResponse = QuerySigningInfoResponse

@typing_extensions.final
class QuerySigningInfosRequest(google.protobuf.message.Message):
    """QuerySigningInfosRequest is the request type for the Query/SigningInfos RPC
    method
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___QuerySigningInfosRequest = QuerySigningInfosRequest

@typing_extensions.final
class QuerySigningInfosResponse(google.protobuf.message.Message):
    """QuerySigningInfosResponse is the response type for the Query/SigningInfos RPC
    method
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo]:
        """info is the signing info of all validators"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...
    def __init__(
        self,
        *,
        info: collections.abc.Iterable[cosmos.slashing.v1beta1.slashing_pb2.ValidatorSigningInfo] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["info", b"info", "pagination", b"pagination"]) -> None: ...

global___QuerySigningInfosResponse = QuerySigningInfosResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ParameterChangeProposal(google.protobuf.message.Message):
    """ParameterChangeProposal defines a proposal to change one or more parameters."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CHANGES_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    @property
    def changes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParamChange]: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        changes: collections.abc.Iterable[global___ParamChange] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["changes", b"changes", "description", b"description", "title", b"title"]) -> None: ...

global___ParameterChangeProposal = ParameterChangeProposal

@typing_extensions.final
class ParamChange(google.protobuf.message.Message):
    """ParamChange defines an individual parameter change, for use in
    ParameterChangeProposal.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSPACE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    subspace: builtins.str
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        subspace: builtins.str = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "subspace", b"subspace", "value", b"value"]) -> None: ...

global___ParamChange = ParamChange



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.twap.v1beta1 import query_pb2 as osmosis_dot_twap_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/osmosis.twap.v1beta1.Query/Params',
                request_serializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ParamsRequest.SerializeToString,
                response_deserializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ParamsResponse.FromString,
                )
        self.ArithmeticTwap = channel.unary_unary(
                '/osmosis.twap.v1beta1.Query/ArithmeticTwap',
                request_serializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapRequest.SerializeToString,
                response_deserializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapResponse.FromString,
                )
        self.ArithmeticTwapToNow = channel.unary_unary(
                '/osmosis.twap.v1beta1.Query/ArithmeticTwapToNow',
                request_serializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapToNowRequest.SerializeToString,
                response_deserializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapToNowResponse.FromString,
                )
        self.GeometricTwap = channel.unary_unary(
                '/osmosis.twap.v1beta1.Query/GeometricTwap',
                request_serializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapRequest.SerializeToString,
                response_deserializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapResponse.FromString,
                )
        self.GeometricTwapToNow = channel.unary_unary(
                '/osmosis.twap.v1beta1.Query/GeometricTwapToNow',
                request_serializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapToNowRequest.SerializeToString,
                response_deserializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapToNowResponse.FromString,
                )


class QueryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Params(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArithmeticTwap(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArithmeticTwapToNow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GeometricTwap(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GeometricTwapToNow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ParamsRequest.FromString,
                    response_serializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ParamsResponse.SerializeToString,
            ),
            'ArithmeticTwap': grpc.unary_unary_rpc_method_handler(
                    servicer.ArithmeticTwap,
                    request_deserializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapRequest.FromString,
                    response_serializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapResponse.SerializeToString,
            ),
            'ArithmeticTwapToNow': grpc.unary_unary_rpc_method_handler(
                    servicer.ArithmeticTwapToNow,
                    request_deserializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapToNowRequest.FromString,
                    response_serializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapToNowResponse.SerializeToString,
            ),
            'GeometricTwap': grpc.unary_unary_rpc_method_handler(
                    servicer.GeometricTwap,
                    request_deserializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapRequest.FromString,
                    response_serializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapResponse.SerializeToString,
            ),
            'GeometricTwapToNow': grpc.unary_unary_rpc_method_handler(
                    servicer.GeometricTwapToNow,
                    request_deserializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapToNowRequest.FromString,
                    response_serializer=osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapToNowResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.twap.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.twap.v1beta1.Query/Params',
            osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ParamsRequest.SerializeToString,
            osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArithmeticTwap(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.twap.v1beta1.Query/ArithmeticTwap',
            osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapRequest.SerializeToString,
            osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArithmeticTwapToNow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.twap.v1beta1.Query/ArithmeticTwapToNow',
            osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapToNowRequest.SerializeToString,
            osmosis_dot_twap_dot_v1beta1_dot_query__pb2.ArithmeticTwapToNowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GeometricTwap(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.twap.v1beta1.Query/GeometricTwap',
            osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapRequest.SerializeToString,
            osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GeometricTwapToNow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.twap.v1beta1.Query/GeometricTwapToNow',
            osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapToNowRequest.SerializeToString,
            osmosis_dot_twap_dot_v1beta1_dot_query__pb2.GeometricTwapToNowResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.crisis.v1beta1.tx_pb2
import grpc

class MsgStub:
    """Msg defines the bank Msg service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    VerifyInvariant: grpc.UnaryUnaryMultiCallable[
        cosmos.crisis.v1beta1.tx_pb2.MsgVerifyInvariant,
        cosmos.crisis.v1beta1.tx_pb2.MsgVerifyInvariantResponse,
    ]
    """VerifyInvariant defines a method to verify a particular invariance."""

class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the bank Msg service."""

    @abc.abstractmethod
    def VerifyInvariant(
        self,
        request: cosmos.crisis.v1beta1.tx_pb2.MsgVerifyInvariant,
        context: grpc.ServicerContext,
    ) -> cosmos.crisis.v1beta1.tx_pb2.MsgVerifyInvariantResponse:
        """VerifyInvariant defines a method to verify a particular invariance."""

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.base.tendermint.v1beta1.query_pb2
import grpc

class ServiceStub:
    """Service defines the gRPC querier service for tendermint queries."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    GetNodeInfo: grpc.UnaryUnaryMultiCallable[
        cosmos.base.tendermint.v1beta1.query_pb2.GetNodeInfoRequest,
        cosmos.base.tendermint.v1beta1.query_pb2.GetNodeInfoResponse,
    ]
    """GetNodeInfo queries the current node info."""
    GetSyncing: grpc.UnaryUnaryMultiCallable[
        cosmos.base.tendermint.v1beta1.query_pb2.GetSyncingRequest,
        cosmos.base.tendermint.v1beta1.query_pb2.GetSyncingResponse,
    ]
    """GetSyncing queries node syncing."""
    GetLatestBlock: grpc.UnaryUnaryMultiCallable[
        cosmos.base.tendermint.v1beta1.query_pb2.GetLatestBlockRequest,
        cosmos.base.tendermint.v1beta1.query_pb2.GetLatestBlockResponse,
    ]
    """GetLatestBlock returns the latest block."""
    GetBlockByHeight: grpc.UnaryUnaryMultiCallable[
        cosmos.base.tendermint.v1beta1.query_pb2.GetBlockByHeightRequest,
        cosmos.base.tendermint.v1beta1.query_pb2.GetBlockByHeightResponse,
    ]
    """GetBlockByHeight queries block for given height."""
    GetLatestValidatorSet: grpc.UnaryUnaryMultiCallable[
        cosmos.base.tendermint.v1beta1.query_pb2.GetLatestValidatorSetRequest,
        cosmos.base.tendermint.v1beta1.query_pb2.GetLatestValidatorSetResponse,
    ]
    """GetLatestValidatorSet queries latest validator-set."""
    GetValidatorSetByHeight: grpc.UnaryUnaryMultiCallable[
        cosmos.base.tendermint.v1beta1.query_pb2.GetValidatorSetByHeightRequest,
        cosmos.base.tendermint.v1beta1.query_pb2.GetValidatorSetByHeightResponse,
    ]
    """GetValidatorSetByHeight queries validator-set at a given height."""

class ServiceServicer(metaclass=abc.ABCMeta):
    """Service defines the gRPC querier service for tendermint queries."""

    @abc.abstractmethod
    def GetNodeInfo(
        self,
        request: cosmos.base.tendermint.v1beta1.query_pb2.GetNodeInfoRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.base.tendermint.v1beta1.query_pb2.GetNodeInfoResponse:
        """GetNodeInfo queries the current node info."""
    @abc.abstractmethod
    def GetSyncing(
        self,
        request: cosmos.base.tendermint.v1beta1.query_pb2.GetSyncingRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.base.tendermint.v1beta1.query_pb2.GetSyncingResponse:
        """GetSyncing queries node syncing."""
    @abc.abstractmethod
    def GetLatestBlock(
        self,
        request: cosmos.base.tendermint.v1beta1.query_pb2.GetLatestBlockRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.base.tendermint.v1beta1.query_pb2.GetLatestBlockResponse:
        """GetLatestBlock returns the latest block."""
    @abc.abstractmethod
    def GetBlockByHeight(
        self,
        request: cosmos.base.tendermint.v1beta1.query_pb2.GetBlockByHeightRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.base.tendermint.v1beta1.query_pb2.GetBlockByHeightResponse:
        """GetBlockByHeight queries block for given height."""
    @abc.abstractmethod
    def GetLatestValidatorSet(
        self,
        request: cosmos.base.tendermint.v1beta1.query_pb2.GetLatestValidatorSetRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.base.tendermint.v1beta1.query_pb2.GetLatestValidatorSetResponse:
        """GetLatestValidatorSet queries latest validator-set."""
    @abc.abstractmethod
    def GetValidatorSetByHeight(
        self,
        request: cosmos.base.tendermint.v1beta1.query_pb2.GetValidatorSetByHeightRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.base.tendermint.v1beta1.query_pb2.GetValidatorSetByHeightResponse:
        """GetValidatorSetByHeight queries validator-set at a given height."""

def add_ServiceServicer_to_server(servicer: ServiceServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.bank.v1beta1.bank_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the bank module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    BALANCES_FIELD_NUMBER: builtins.int
    SUPPLY_FIELD_NUMBER: builtins.int
    DENOM_METADATA_FIELD_NUMBER: builtins.int
    SUPPLY_OFFSETS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.bank.v1beta1.bank_pb2.Params:
        """params defines all the paramaters of the module."""
    @property
    def balances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Balance]:
        """balances is an array containing the balances of all the accounts."""
    @property
    def supply(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """supply represents the total supply. If it is left empty, then supply will be calculated based on the provided
        balances. Otherwise, it will be used to validate that the sum of the balances equals this amount.
        """
    @property
    def denom_metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.bank.v1beta1.bank_pb2.Metadata]:
        """denom_metadata defines the metadata of the differents coins."""
    @property
    def supply_offsets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenesisSupplyOffset]:
        """supply_offsets defines the amount of supply offset."""
    def __init__(
        self,
        *,
        params: cosmos.bank.v1beta1.bank_pb2.Params | None = ...,
        balances: collections.abc.Iterable[global___Balance] | None = ...,
        supply: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        denom_metadata: collections.abc.Iterable[cosmos.bank.v1beta1.bank_pb2.Metadata] | None = ...,
        supply_offsets: collections.abc.Iterable[global___GenesisSupplyOffset] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["balances", b"balances", "denom_metadata", b"denom_metadata", "params", b"params", "supply", b"supply", "supply_offsets", b"supply_offsets"]) -> None: ...

global___GenesisState = GenesisState

@typing_extensions.final
class Balance(google.protobuf.message.Message):
    """Balance defines an account address and balance pair used in the bank module's
    genesis state.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """address is the address of the balance holder."""
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """coins defines the different coins this balance holds."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "coins", b"coins"]) -> None: ...

global___Balance = Balance

@typing_extensions.final
class GenesisSupplyOffset(google.protobuf.message.Message):
    """GenesisSupplyOffset encodes the supply offsets, just for genesis.
    The offsets are serialized directly by denom in state.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    denom: builtins.str
    """Denom"""
    offset: builtins.str
    """SupplyOffset"""
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        offset: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom", "offset", b"offset"]) -> None: ...

global___GenesisSupplyOffset = GenesisSupplyOffset



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.crypto.multisig.v1beta1.multisig_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SignMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SignModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SignMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SIGN_MODE_UNSPECIFIED: _SignMode.ValueType  # 0
    """SIGN_MODE_UNSPECIFIED specifies an unknown signing mode and will be
    rejected
    """
    SIGN_MODE_DIRECT: _SignMode.ValueType  # 1
    """SIGN_MODE_DIRECT specifies a signing mode which uses SignDoc and is
    verified with raw bytes from Tx
    """
    SIGN_MODE_TEXTUAL: _SignMode.ValueType  # 2
    """SIGN_MODE_TEXTUAL is a future signing mode that will verify some
    human-readable textual representation on top of the binary representation
    from SIGN_MODE_DIRECT
    """
    SIGN_MODE_LEGACY_AMINO_JSON: _SignMode.ValueType  # 127
    """SIGN_MODE_LEGACY_AMINO_JSON is a backwards compatibility mode which uses
    Amino JSON and will be removed in the future
    """
    SIGN_MODE_EIP_191: _SignMode.ValueType  # 191
    """SIGN_MODE_EIP_191 specifies the sign mode for EIP 191 signing on the Cosmos
    SDK. Ref: https://eips.ethereum.org/EIPS/eip-191

    Currently, SIGN_MODE_EIP_191 is registered as a SignMode enum variant,
    but is not implemented on the SDK by default. To enable EIP-191, you need
    to pass a custom `TxConfig` that has an implementation of
    `SignModeHandler` for EIP-191. The SDK may decide to fully support
    EIP-191 in the future.

    Since: cosmos-sdk 0.45.2
    """

class SignMode(_SignMode, metaclass=_SignModeEnumTypeWrapper):
    """SignMode represents a signing mode with its own security guarantees."""

SIGN_MODE_UNSPECIFIED: SignMode.ValueType  # 0
"""SIGN_MODE_UNSPECIFIED specifies an unknown signing mode and will be
rejected
"""
SIGN_MODE_DIRECT: SignMode.ValueType  # 1
"""SIGN_MODE_DIRECT specifies a signing mode which uses SignDoc and is
verified with raw bytes from Tx
"""
SIGN_MODE_TEXTUAL: SignMode.ValueType  # 2
"""SIGN_MODE_TEXTUAL is a future signing mode that will verify some
human-readable textual representation on top of the binary representation
from SIGN_MODE_DIRECT
"""
SIGN_MODE_LEGACY_AMINO_JSON: SignMode.ValueType  # 127
"""SIGN_MODE_LEGACY_AMINO_JSON is a backwards compatibility mode which uses
Amino JSON and will be removed in the future
"""
SIGN_MODE_EIP_191: SignMode.ValueType  # 191
"""SIGN_MODE_EIP_191 specifies the sign mode for EIP 191 signing on the Cosmos
SDK. Ref: https://eips.ethereum.org/EIPS/eip-191

Currently, SIGN_MODE_EIP_191 is registered as a SignMode enum variant,
but is not implemented on the SDK by default. To enable EIP-191, you need
to pass a custom `TxConfig` that has an implementation of
`SignModeHandler` for EIP-191. The SDK may decide to fully support
EIP-191 in the future.

Since: cosmos-sdk 0.45.2
"""
global___SignMode = SignMode

@typing_extensions.final
class SignatureDescriptors(google.protobuf.message.Message):
    """SignatureDescriptors wraps multiple SignatureDescriptor's."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURES_FIELD_NUMBER: builtins.int
    @property
    def signatures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SignatureDescriptor]:
        """signatures are the signature descriptors"""
    def __init__(
        self,
        *,
        signatures: collections.abc.Iterable[global___SignatureDescriptor] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["signatures", b"signatures"]) -> None: ...

global___SignatureDescriptors = SignatureDescriptors

@typing_extensions.final
class SignatureDescriptor(google.protobuf.message.Message):
    """SignatureDescriptor is a convenience type which represents the full data for
    a signature including the public key of the signer, signing modes and the
    signature itself. It is primarily used for coordinating signatures between
    clients.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Data(google.protobuf.message.Message):
        """Data represents signature data"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing_extensions.final
        class Single(google.protobuf.message.Message):
            """Single is the signature data for a single signer"""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            MODE_FIELD_NUMBER: builtins.int
            SIGNATURE_FIELD_NUMBER: builtins.int
            mode: global___SignMode.ValueType
            """mode is the signing mode of the single signer"""
            signature: builtins.bytes
            """signature is the raw signature bytes"""
            def __init__(
                self,
                *,
                mode: global___SignMode.ValueType = ...,
                signature: builtins.bytes = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode", "signature", b"signature"]) -> None: ...

        @typing_extensions.final
        class Multi(google.protobuf.message.Message):
            """Multi is the signature data for a multisig public key"""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            BITARRAY_FIELD_NUMBER: builtins.int
            SIGNATURES_FIELD_NUMBER: builtins.int
            @property
            def bitarray(self) -> cosmos.crypto.multisig.v1beta1.multisig_pb2.CompactBitArray:
                """bitarray specifies which keys within the multisig are signing"""
            @property
            def signatures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SignatureDescriptor.Data]:
                """signatures is the signatures of the multi-signature"""
            def __init__(
                self,
                *,
                bitarray: cosmos.crypto.multisig.v1beta1.multisig_pb2.CompactBitArray | None = ...,
                signatures: collections.abc.Iterable[global___SignatureDescriptor.Data] | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal["bitarray", b"bitarray"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal["bitarray", b"bitarray", "signatures", b"signatures"]) -> None: ...

        SINGLE_FIELD_NUMBER: builtins.int
        MULTI_FIELD_NUMBER: builtins.int
        @property
        def single(self) -> global___SignatureDescriptor.Data.Single:
            """single represents a single signer"""
        @property
        def multi(self) -> global___SignatureDescriptor.Data.Multi:
            """multi represents a multisig signer"""
        def __init__(
            self,
            *,
            single: global___SignatureDescriptor.Data.Single | None = ...,
            multi: global___SignatureDescriptor.Data.Multi | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["multi", b"multi", "single", b"single", "sum", b"sum"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["multi", b"multi", "single", b"single", "sum", b"sum"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["sum", b"sum"]) -> typing_extensions.Literal["single", "multi"] | None: ...

    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    @property
    def public_key(self) -> google.protobuf.any_pb2.Any:
        """public_key is the public key of the signer"""
    @property
    def data(self) -> global___SignatureDescriptor.Data: ...
    sequence: builtins.int
    """sequence is the sequence of the account, which describes the
    number of committed transactions signed by a given address. It is used to prevent
    replay attacks.
    """
    def __init__(
        self,
        *,
        public_key: google.protobuf.any_pb2.Any | None = ...,
        data: global___SignatureDescriptor.Data | None = ...,
        sequence: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data", "public_key", b"public_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "public_key", b"public_key", "sequence", b"sequence"]) -> None: ...

global___SignatureDescriptor = SignatureDescriptor



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class StoreKVPair(google.protobuf.message.Message):
    """StoreKVPair is a KVStore KVPair used for listening to state changes (Sets and Deletes)
    It optionally includes the StoreKey for the originating KVStore and a Boolean flag to distinguish between Sets and
    Deletes

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORE_KEY_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    store_key: builtins.str
    """the store key for the KVStore this pair originates from"""
    delete: builtins.bool
    """true indicates a delete operation, false indicates a set operation"""
    key: builtins.bytes
    value: builtins.bytes
    def __init__(
        self,
        *,
        store_key: builtins.str = ...,
        delete: builtins.bool = ...,
        key: builtins.bytes = ...,
        value: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete", b"delete", "key", b"key", "store_key", b"store_key", "value", b"value"]) -> None: ...

global___StoreKVPair = StoreKVPair
